

           Arcade Emulators Center  for win95
           ----------------------------------

                      Version 1.11

                   by Marc Lafontaine

This program is Freeware.

To Contact me:
  Email: marclaf@sympatico.ca
    Web: www3.sympatico.ca/marclaf


What is Arcade Emulators Center:
-------------------------------

  Arcade Emulators Center is a program that launch many Arcade Emulators.

For the Mame emulator, you can use the integrated Mame Games Manager.
It will help you keep track of the multiple directorys required by Mame.
He can scan for new games, detect not used directorys, create the
directorys for you, create a list of the names of the Roms that
are required for a game. It can dezip the zip file that content the roms
for a game in the proper directory.


Why did I write this program:
----------------------------

  I needed something to manage the multiple directorys required by Mame.
  I wanted a program that present the games in a multiple button box instead
  of a listbox.


How to use Arcade Emulators Center:
----------------------------------

  -Before you start the program, make sure the program is not on a CD-ROM
    disk because, he will not be able to save its configuration file.
    If the program is on a CD-ROM, you better copy it on your hard drive.
  -When you start the program for the first time, the first screen (START)
    is empty. You must configure the emulators path that are in the other
    pages. All path and options are saved in the .INI file when you exit
    the program. So, if you reset your computer after changing an option,
    before closing the program, the changes will be lost.
  -For emulators with multiple games like MAME, KEM, Replay and in the
    Custom page, you have buttons to ADD,EDIT and DELETE games from the list.
    The ON/OFF button is to Enable/Disable the game from the START list.
    It is useful for the games that you haven't got the rom images yet
    or for games you don't like.
    Double Click on a name in the list do the same than the button ON/OFF.
  -For MAME you have a button MANAGER, this button will call the
    Mame Games Manager, more on that later.
  -When you have configured one or more emulators, you start the games
    in the START page. First, click on the game you want to play, then
    click on the LAUNCH button. Or, if you want to view or enter an
    hi-score, click on the View/Enter hi-scores button. Note that those
    hi-scores are in the .ini file and do not reflect what you have in
    the game itself. This feature was useful when emulators did not save
    their hi-scores but today its pretty useless.
  -All the emulators I support can be downloaded from
     Dave's Classic Video Game web page at:
        http://www.gamepen.com/gamewire/classic/classic.html
    except for Williams emulator that is a commercial program.
  -Don't ask me for rom images.


Options:
--------
  -In the Start screen, you have the Options button, when pressed it will
    display the Options requester.
   -Style:
    -I think it is self explanatory. Try it and see what happen.
   -Sort:
    -Normal will sort the games alphabetically
    -Mame games first, will put all the Mame games before the others.
      the others will be sorted like in Normal mode.
    -Mame games last, will put all the Mame games after the others.
      the others will be sorted like in Normal mode.
    -by Sort Key, will sort with the Sort Key that appear in each pages
      of games configuration. This will sort the games by Emulator order.
      If you want to merge two or more emulators games together, put the
      same number in the Sort Key of the wanted Emulators.
   -Tab Style
    -Try it and see what you prefer.
   -Show Emulators name:
     -If checked, each game in the list will be followed by its Emulator name.
        EX.: Centipede (MAME)
   -Nb of Items by pages max:
     Number of games by bank of games.
     The program try to put an equal number of games by pages.
     So, if you have 100 games:
      -If the number is 50 you will have 2 pages of 50 games.
      -If the number is 49 you will have 3 pages, 33,33,34.

Mame Games Manager:
------------------
The goal of this section of my program is to help the user to determine
what are the new games of a new version of Mame. It can tell you which
games you do not have the ROMs yet and which games are not supported
by Mame anymore. It can create all the directory for you. It can
create text file that content the names of the needed roms.
Or it can do a complete list of all the roms for all the games
supported by mame.
In a next version I want that section to be able to search for
the roms itself by scanning the Zips that are in a specified location.
So you would just have to press one button and it will do all the
job for you.

  -To enter the Mame Roms Manager press the Manager button in the Mame section.
  -There is a Popup menu for the list box, you can use it to work on one
    game instead of pressing the buttons.

  -The buttons:
   -SCAN
     When you receive a new version of Mame or if you want to see
     what rom directory are missing, press that button.
     It will call Mame to ask him what are the games that are
     supported by this version.
     After collecting the list of games, it will update the list.
     The new games will appear in Magenta. The games that are not
     supported anymore by Mame will appear in Red.
     After that, it will check if all the directory are created
     or, if created, it will count the number of files in it.
     If a directory is not there or if he has no more than 2 files
     in it, the game will appear in Blue in the list.
     If a directory is found in the MAME directory but not reported
     by Mame, this directory will be listed in the 'Dirs not used' list box.
     It call MAME -LIST  so it will not work if Mame do not support
     the -list option.
   -INSTALL ROMS:
     Select this and a file requester will appear.
     Select the Zip file that content the roms for that game.
     The zip file will be dezipped in the appropriate directory.
   -SHOW ROMS NAME
     By pressing that button, the program will show you the names
     of the roms that are required for the currently selected game to start.
   -CREATE DIRECTORY
     If you click this button, the program will create all the directory
     required for each game in the list.
     To create a directory for only one game, Right click on it and choose
     Create Dir in the Popup menu.
   -EDIT
     To edit the name and parameters of the selected game
   -DELETE
     Delete the selected game
   -OK
     Press it to exit MAME Roms Manager.
   -CANCEL
     To exit without keeping the last modifications to the list.
   -SORT BY COLORS
     Change the order of the games in the list.

  -Stats: These stats are displayed after you pressed the SCAN button.
   -MAME support XXX Games.
     This is the number of games currently supported by MAME as reported
     by the -list option of MAME.
   -XXX games that you probably can play.
     This is the number of games that are probably functional.
     This number is the total number of games - the Magenta - the Blue ones.
   -XX New games (Magenta)
     The number of new games found. This is the number of games that are in the
     list reported by the -list option of Mame that where not in your game list.
   -XX games with empty or missing directory. (Blue)
     The number of games that there where no rom directory found or if that
     directory contain less that 2 files.
   -XX games are not used by Mame.(Red)
     the number of games that where in your game list but that where not reported
     the the -list option of Mame.


Version History
---------------
 7/14/1998 -- Version 1.11
     -Updated for Mame 0.33b6
     -Maximum of games is now at 1000 instead of 500

 10/22/1997 -- Version 1.10
     -Now resizable and has an illimited number of banks
       Solve the problem of having too many games in the Start screen.
     -Updated for Mame 0.29
       -When installing a new game for Mame, choose the option Install Game
         then just click on the Zip file that content the roms and it will be
         dezipped in the required directory.
       -Added a button to set the command line parameters for a selected game.
         So you will not have to type yourself the commands when you have
         to specify special options for a game.
     -Updated for new version of others emulators

 6/02/1997 -- Version 1.01
     -Splitted the START section in 2 or 3 banks, no need to use the
        list box when you have more than 80 games anymore.
     -You now have many options to sort the games.
     -Added Mame Roms Manager
      -Detect new games automatically
      -Detect Missing directorys
      -Detect directorys that are not used anymore
      -Can create required Directorys
      -Can display the required Roms names for a game
      -Can create a Rom list in a game directory or create a
        complete list of all the roms for all the games.
     -Added SAGE 1.15 support
     -Updated for Mame 0.22
     -Updated for M-Ulator 0.11
     -Updated for KEM BETA 04
     -Updated for Replay 0.03

 4/25/1997 -- Version 1.00
     -Added an editable list for Mame games, so the new games can be added by
        the user.
     -Support for KEM with an editable list.
     -Support for Replay with an editable list.
     -The Custom page is changed for a list, you are not limited at 4 anymore.
     -In the Mame page, the program can create the directory for the games.
     -Updated the other emulators
     -I drop the Rygar emulators, I needed space for M-ulator, and
       they are easily configurable in the Custom page.
     -Fixed various little bugs.

 3/19/1997 -- Version 0.91
     -Added new games of Mame v0.11
     -Added Rygar (REM! and Rygar)
     -Added M-ulator
     -Added System 16
     -Added Nemesis
     -Write scores in ROM for new games:
       -Burger Time
       -Centipede
       -Donkey Kong 3
       -Nibbler

  3/8/1997 -- Version 0.90

     -First version (beta version)
     -Write hi-score in ROM is supported only for 5 games.


Disclaimer:
----------

Arcade Emulators Center may be made freely available from Internet web sites
as long as the original zip file is not modified in any way.

Attempting to sell Arcade Emulators Center or distribute it with
game ROM code constitutes a violation of copyright and may result
in legal action being taken.

Anyone using this program does so at their own risk.  The author does not
accept any liability for loss or damage arising from its use.

The author will not be held responsible for copyright violations by users of
the emulators.  Users are reminded that the games supported are copyrighted
and should not be distributed without permission.


How to Contact me:
-----------------

  Email: marclaf@sympatico.ca
    Web: www3.sympatico.ca/marclaf

You can contact me by mail at:
   Marc Lafontaine
   904 Terrasse des Promenades
   Drummondville
   Quebec, Canada
   J2C-7B2


BTW: Excuse my english.
